*****************************************************************
:mod:`mopidy.mixers.denon` -- Hardware mixer for Denon amplifiers
*****************************************************************

.. inheritance-diagram:: mopidy.mixers.denon

.. automodule:: mopidy.mixers.denon
    :synopsis: Hardware mixer for Denon amplifiers
    :members:
